@@ -1,3 +1,4 @@
+import six
 import datetime
 
 from django.db import models
@@ -177,9 +178,9 @@ class SettingsTestCase(test.TestCase):
                           'list_comma', 'date', 'time', 'datetime', 'enabled'])
 
         # Values should be coerced to the proper Python types
-        self.assert_(isinstance(Populated.settings.boolean, bool))
-        self.assert_(isinstance(Populated.settings.integer, int))
-        self.assert_(isinstance(Populated.settings.string, basestring))
+        self.assertTrue(isinstance(Populated.settings.boolean, bool))
+        self.assertTrue(isinstance(Populated.settings.integer, int))
+        self.assertTrue(isinstance(Populated.settings.string, six.string_types))
 
         # Settings can not be accessed directly from models, only instances
         self.assertRaises(AttributeError, lambda: Populated().settings)
@@ -254,8 +255,8 @@ class SettingsTestCase(test.TestCase):
         self.assertRaises(TypeError, curry(type, 'BadGroup', (dbsettings.Group,), attrs))
 
         # Make sure affect models get the new permissions
-        self.assert_('can_edit_populated_settings' in dict(Populated._meta.permissions))
-        self.assert_('can_edit_unpopulated_settings' in dict(Unpopulated._meta.permissions))
+        self.assertTrue('can_edit_populated_settings' in dict(Populated._meta.permissions))
+        self.assertTrue('can_edit_unpopulated_settings' in dict(Unpopulated._meta.permissions))
 
     def assertCorrectSetting(self, value_class, *key):
         from dbsettings import loading
@@ -353,10 +354,19 @@ class SettingsTestCase(test.TestCase):
         self.assertEqual(Editable.settings.time, datetime.time(16, 37, 45))
         self.assertEqual(Editable.settings.datetime, datetime.datetime(2012, 6, 28, 16, 37, 45))
 
-        # Check if module / class settings show properly
-        #perm = Permission.objects.get(codename='can_edit__settings')  # module-level settings
-        #user.user_permissions.add(perm)
+        # Check if module level settings show properly
+        self._test_form_fields(site_form, 8, False)
+        # Add perm for whole app
+        perm = Permission.objects.get(codename='can_edit__settings')  # module-level settings
+        user.user_permissions.add(perm)
+        self._test_form_fields(site_form, 18)
+        # Remove other perms - left only global perm
+        perm = Permission.objects.get(codename='can_edit_editable_settings')
+        user.user_permissions.remove(perm)
+        self._test_form_fields(site_form, 10)
 
-        #response = self.client.get(site_form)
-        #self.assertTemplateUsed(response, 'dbsettings/site_settings.html')
-        #self.assertEqual(len(response.context[0]['form'].fields), 14)
+    def _test_form_fields(self, url, fields_num, present=True, variable_name='form'):
+        global_setting = 'dbsettings.tests____clash2'  # Some global setting name
+        response = self.client.get(url)
+        self.assertEqual(present, global_setting in response.context[0][variable_name].fields.keys())
+        self.assertEqual(len(response.context[0][variable_name].fields), fields_num)
