@@ -1,4 +1,8 @@
-from django.conf.urls.defaults import *
+try:
+    from django.conf.urls import patterns, include
+except ImportError:
+    # Django 1.3
+    from django.conf.urls.defaults import patterns, include
 from django.contrib import admin
 
 urlpatterns = patterns('',
