@@ -1,4 +1,8 @@
-from django.conf.urls.defaults import patterns, url
+try:
+    from django.conf.urls import patterns, url
+except ImportError:
+    # Django 1.3
+    from django.conf.urls.defaults import patterns, url
 
 urlpatterns = patterns('dbsettings.views',
     url(r'^$', 'site_settings', name='site_settings'),
