@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-from django import VERSION as DJANGO_VERSION
 from django.conf import settings
 from django.core.management import call_command
 
@@ -19,20 +18,13 @@ SETTINGS = {
     'INSTALLED_APPS': INSTALLED_APPS,
     'SITE_ID': 1,
     'ROOT_URLCONF': 'dbsettings.tests.test_urls',
-}
-
-if DJANGO_VERSION > (1, 2):
-    # Post multi-db settings.
-    SETTINGS['DATABASES'] = {
+    'DATABASES': {
         'default': {
             'ENGINE': 'django.db.backends.sqlite3',
             'NAME': ':memory:',
         }
-    }
-else:
-    # Pre multi-db settings.
-    SETTINGS['DATABASE_ENGINE'] = 'sqlite3'
-    SETTINGS['DATABASE_NAME'] = ':memory:'
+    },
+}
 
 if not settings.configured:
     settings.configure(**SETTINGS)
